@@ -473,8 +473,8 @@ Draft4Validator = create(
         u"$ref": _validators.ref,
         u"additionalItems": _validators.additionalItems,
         u"additionalProperties": _validators.additionalProperties,
-        u"allOf": _legacy_validators.allOf_draft4,
-        u"anyOf": _legacy_validators.anyOf_draft4,
+        u"allOf": _validators.allOf,
+        u"anyOf": _validators.anyOf,
         u"dependencies": _validators.dependencies,
         u"enum": _validators.enum,
         u"format": _validators.format,
@@ -489,7 +489,7 @@ Draft4Validator = create(
         u"minimum": _legacy_validators.minimum_draft3_draft4,
         u"multipleOf": _validators.multipleOf,
         u"not": _validators.not_,
-        u"oneOf": _legacy_validators.oneOf_draft4,
+        u"oneOf": _validators.oneOf,
         u"pattern": _validators.pattern,
         u"patternProperties": _validators.patternProperties,
         u"properties": _validators.properties,
